-- Generated from doc/commands-xml/commands.xml by "sphelper genschema". Do not edit.
return {
    ["A"] = {["bordercolor"] = true, ["description"] = true, ["embedded"] = true, ["href"] = true, ["link"] = true, ["page"] = true },
    ["AddSearchpath"] = {["select"] = true },
    ["AtPageCreation"] = {["graphic"] = true },
    ["AtPageShipout"] = {["graphic"] = true },
    ["AttachFile"] = {["filename"] = true, ["description"] = true, ["type"] = true, ["name"] = true, ["select"] = true },
    ["Axis"] = {["name"] = true, ["value"] = true },
    ["Attribute"] = {["name"] = true, ["select"] = true },
    ["B"] = { },
    ["Barcode"] = {["color"] = true, ["eclevel"] = true, ["fontfamily"] = true, ["height"] = true, ["keepfontsize"] = true, ["overshoot"] = true, ["select"] = true, ["showtext"] = true, ["type"] = true, ["width"] = true },
    ["Bold"] = {["fontface"] = true },
    ["BoldItalic"] = {["fontface"] = true },
    ["Bookmark"] = {["level"] = true, ["open"] = true, ["select"] = true },
    ["Box"] = {["background-color"] = true, ["border-color"] = true, ["border-width"] = true, ["bleed"] = true, ["class"] = true, ["graphic"] = true, ["height"] = true, ["id"] = true, ["padding-top"] = true, ["padding-bottom"] = true, ["padding-left"] = true, ["padding-right"] = true, ["vertical-align"] = true, ["width"] = true },
    ["Br"] = { },
    ["Case"] = {["test"] = true },
    ["Circle"] = {["background-color"] = true, ["class"] = true, ["framecolor"] = true, ["id"] = true, ["radiusx"] = true, ["radiusy"] = true, ["rulewidth"] = true },
    ["ClearPage"] = {["force"] = true, ["matter"] = true, ["openon"] = true, ["pagetype"] = true, ["skippagetype"] = true },
    ["Clip"] = {["left"] = true, ["top"] = true, ["right"] = true, ["bottom"] = true, ["width"] = true, ["height"] = true, ["method"] = true },
    ["Color"] = {["name"] = true },
    ["Column"] = {["align"] = true, ["background-color"] = true, ["minwidth"] = true, ["padding-left"] = true, ["padding-right"] = true, ["width"] = true, ["valign"] = true },
    ["Columns"] = { },
    ["Compatibility"] = {["movecursoronplaceobject"] = true },
    ["Contents"] = { },
    ["Copy-of"] = {["select"] = true },
    ["DefineColorprofile"] = {["condition"] = true, ["colors"] = true, ["filename"] = true, ["identifier"] = true, ["info"] = true, ["name"] = true, ["registry"] = true },
    ["DefineColor"] = {["alpha"] = true, ["colorname"] = true, ["model"] = true, ["name"] = true, ["overprint"] = true, ["saturation"] = true, ["usecolorprofile"] = true, ["value"] = true, ["r"] = true, ["g"] = true, ["b"] = true, ["c"] = true, ["m"] = true, ["y"] = true, ["k"] = true },
    ["DefineGraphic"] = {["name"] = true },
    ["DefineFontalias"] = {["alias"] = true, ["existing"] = true },
    ["DefineFontfamily"] = {["fontsize"] = true, ["leading"] = true, ["name"] = true, ["scriptsize"] = true, ["subshift"] = true, ["supershift"] = true },
    ["DefineMatter"] = {["name"] = true, ["prefix"] = true, ["label"] = true, ["resetafter"] = true, ["resetbefore"] = true },
    ["DefineTextformat"] = {["alignment"] = true, ["border-top"] = true, ["border-bottom"] = true, ["break-before"] = true, ["break-below"] = true, ["column-padding-top"] = true, ["cssfontsize"] = true, ["fill-last-line"] = true, ["hyphenchar"] = true, ["hyphenate"] = true, ["indentation"] = true, ["letter-spacing"] = true, ["margin-bottom"] = true, ["margin-top"] = true, ["margin-top-box-start"] = true, ["name"] = true, ["orphan"] = true, ["padding-top"] = true, ["rows"] = true, ["tab"] = true, ["html-vertical-spacing"] = true, ["widow"] = true },
    ["Element"] = {["name"] = true },
    ["Fallback"] = {["filename"] = true },
    ["Fontface"] = {["fontfamily"] = true },
    ["ForAll"] = {["select"] = true, ["limit"] = true, ["start"] = true },
    ["Frame"] = {["background-color"] = true, ["border-bottom-right-radius"] = true, ["border-top-right-radius"] = true, ["border-top-left-radius"] = true, ["border-bottom-left-radius"] = true, ["border-radius"] = true, ["framecolor"] = true, ["rulewidth"] = true, ["class"] = true, ["id"] = true, ["clip"] = true },
    ["Function"] = {["name"] = true },
    ["Grid"] = {["width"] = true, ["height"] = true, ["nx"] = true, ["ny"] = true, ["dx"] = true, ["dy"] = true },
    ["Group"] = {["name"] = true },
    ["Groupcontents"] = {["name"] = true },
    ["HTML"] = {["expand-text"] = true, ["select"] = true },
    ["Hyphenation"] = {["language"] = true },
    ["HSpace"] = {["leader"] = true, ["leader-width"] = true, ["minwidth"] = true, ["width"] = true },
    ["I"] = { },
    ["Include"] = {["xml:base"] = true },
    ["Initial"] = {["color"] = true, ["fontfamily"] = true, ["padding-left"] = true, ["padding-right"] = true, ["padding-top"] = true, ["padding-bottom"] = true },
    ["InsertPages"] = {["name"] = true, ["pages"] = true },
    ["Image"] = {["class"] = true, ["id"] = true, ["bleed"] = true, ["clip"] = true, ["description"] = true, ["dpiwarn"] = true, ["fallback"] = true, ["file"] = true, ["height"] = true, ["imageshape"] = true, ["parent"] = true, ["page"] = true, ["margin-bottom"] = true, ["margin-top"] = true, ["margin-left"] = true, ["margin-right"] = true, ["maxwidth"] = true, ["maxheight"] = true, ["minwidth"] = true, ["minheight"] = true, ["opacity"] = true, ["padding"] = true, ["padding-top"] = true, ["padding-bottom"] = true, ["padding-left"] = true, ["padding-right"] = true, ["stretch"] = true, ["role"] = true, ["rotate"] = true, ["visiblebox"] = true, ["vertical-align"] = true, ["width"] = true, ["imagetype"] = true },
    ["Italic"] = {["fontface"] = true },
    ["LoadDataset"] = {["name"] = true, ["filename"] = true },
    ["LoadFontfile"] = {["name"] = true, ["features"] = true, ["filename"] = true, ["marginprotrusion"] = true, ["mode"] = true, ["oldstylefigures"] = true, ["smallcaps"] = true, ["space"] = true, ["stretch"] = true, ["shrink"] = true, ["step"] = true, ["weight"] = true, ["width"] = true },
    ["Layout"] = {["version"] = true, ["name"] = true, ["require"] = true },
    ["Li"] = { },
    ["Loop"] = {["select"] = true, ["variable"] = true },
    ["Makeindex"] = {["pagenumber"] = true, ["section"] = true, ["select"] = true, ["sortkey"] = true },
    ["Margin"] = {["left"] = true, ["right"] = true, ["inner"] = true, ["outer"] = true, ["top"] = true, ["bottom"] = true },
    ["Mark"] = {["append"] = true, ["select"] = true, ["shiftup"] = true, ["pdftarget"] = true },
    ["Message"] = {["select"] = true, ["error"] = true, ["errorcode"] = true, ["exit"] = true },
    ["NextFrame"] = {["area"] = true },
    ["NextRow"] = {["area"] = true, ["row"] = true, ["rows"] = true },
    ["NoBreak"] = {["maxwidth"] = true, ["reduce"] = true, ["text"] = true, ["factor"] = true, ["fontfamily"] = true },
    ["Ol"] = {["fontfamily"] = true },
    ["Options"] = {["background-color"] = true, ["bleed"] = true, ["bleedmarks"] = true, ["crop"] = true, ["cutmarks"] = true, ["defaultarea"] = true, ["ignoreeol"] = true, ["html"] = true, ["imagenotfound"] = true, ["interaction"] = true, ["mainlanguage"] = true, ["markdown-extensions"] = true, ["mpcolorwarning"] = true, ["namespaces"] = true, ["randomseed"] = true, ["overfull-line"] = true, ["resetmarks"] = true, ["reportmissingglyphs"] = true, ["startpage"] = true, ["fontexpansion"] = true, ["fontstretch"] = true, ["fontshrink"] = true, ["fontstep"] = true, ["tablerulefix"] = true },
    ["Otherwise"] = { },
    ["Output"] = {["allocate"] = true, ["area"] = true, ["balance"] = true, ["last-padding-bottom-max"] = true, ["row"] = true, ["valign-last"] = true, ["width"] = true },
    ["Overlay"] = { },
    ["Paragraph"] = {["class"] = true, ["id"] = true, ["actualtext"] = true, ["allowbreak"] = true, ["bidi"] = true, ["color"] = true, ["direction"] = true, ["fontfamily"] = true, ["font-outline"] = true, ["html"] = true, ["label-left"] = true, ["label-left-width"] = true, ["label-left-align"] = true, ["label-left-distance"] = true, ["language"] = true, ["padding-left"] = true, ["padding-right"] = true, ["parent"] = true, ["role"] = true, ["structpos"] = true, ["textformat"] = true },
    ["Param"] = {["name"] = true },
    ["Pageformat"] = {["height"] = true, ["width"] = true },
    ["Pagetype"] = {["columnordering"] = true, ["background-color"] = true, ["defaultcolor"] = true, ["name"] = true, ["width"] = true, ["height"] = true, ["part"] = true, ["test"] = true },
    ["PDFOptions"] = {["author"] = true, ["colorprofile"] = true, ["creator"] = true, ["displaymode"] = true, ["dpi"] = true, ["duplex"] = true, ["format"] = true, ["hyperlinkbordercolor"] = true, ["hyperlinkborderwidth"] = true, ["keywords"] = true, ["numcopies"] = true, ["pagelayout"] = true, ["picktraybypdfsize"] = true, ["printscaling"] = true, ["producer"] = true, ["showbookmarks"] = true, ["showhyperlinks"] = true, ["subject"] = true, ["title"] = true },
    ["PlaceObject"] = {["allocate"] = true, ["allocate-left"] = true, ["allocate-right"] = true, ["allocate-top"] = true, ["allocate-bottom"] = true, ["area"] = true, ["background"] = true, ["background-color"] = true, ["border-bottom-right-radius"] = true, ["border-top-right-radius"] = true, ["border-top-left-radius"] = true, ["border-bottom-left-radius"] = true, ["clipatmargin"] = true, ["column"] = true, ["frame"] = true, ["framecolor"] = true, ["groupname"] = true, ["hreference"] = true, ["halign"] = true, ["keepposition"] = true, ["maxheight"] = true, ["origin-x"] = true, ["origin-y"] = true, ["page"] = true, ["row"] = true, ["rotate"] = true, ["rulewidth"] = true, ["valign"] = true, ["vreference"] = true },
    ["Position"] = {["x"] = true, ["y"] = true },
    ["PositioningArea"] = {["name"] = true, ["framecolor"] = true },
    ["PositioningFrame"] = {["width"] = true, ["height"] = true, ["row"] = true, ["column"] = true },
    ["ProcessNode"] = {["limit"] = true, ["select"] = true, ["mode"] = true },
    ["Record"] = {["element"] = true, ["match"] = true, ["mode"] = true },
    ["Regular"] = {["fontface"] = true },
    ["Rule"] = {["direction"] = true, ["rulewidth"] = true, ["length"] = true, ["color"] = true, ["dashed"] = true },
    ["SaveDataset"] = {["name"] = true, ["elementname"] = true, ["select"] = true, ["attributes"] = true },
    ["SavePages"] = {["name"] = true },
    ["Section"] = {["name"] = true },
    ["SetGrid"] = {["width"] = true, ["height"] = true, ["nx"] = true, ["ny"] = true, ["dx"] = true, ["dy"] = true },
    ["SetVariable"] = {["variable"] = true, ["select"] = true, ["type"] = true, ["trace"] = true, ["execute"] = true },
    ["SortSequence"] = {["select"] = true, ["removeduplicates"] = true, ["criterion"] = true, ["numerical"] = true, ["order"] = true },
    ["Span"] = {["class"] = true, ["id"] = true, ["background-color"] = true, ["background-padding-top"] = true, ["background-padding-bottom"] = true, ["fontfamily"] = true, ["language"] = true, ["letter-spacing"] = true, ["role"] = true },
    ["Sub"] = { },
    ["Sup"] = { },
    ["Switch"] = { },
    ["StructureElement"] = {["id"] = true, ["parent"] = true, ["role"] = true },
    ["Stylesheet"] = {["filename"] = true },
    ["Table"] = {["balance"] = true, ["border-collapse"] = true, ["break-pagetype"] = true, ["columndistance"] = true, ["eval"] = true, ["eval-on-split"] = true, ["fontfamily"] = true, ["leading"] = true, ["padding"] = true, ["stretch"] = true, ["parent"] = true, ["role"] = true, ["textformat"] = true, ["width"] = true, ["vexcess"] = true },
    ["Tablefoot"] = {["page"] = true },
    ["Tablehead"] = {["page"] = true },
    ["TableNewPage"] = { },
    ["Td"] = {["class"] = true, ["id"] = true, ["align"] = true, ["background-color"] = true, ["background-font-family"] = true, ["background-textcolor"] = true, ["background-size"] = true, ["background-transform"] = true, ["background-text"] = true, ["border-left"] = true, ["border-right"] = true, ["border-top"] = true, ["border-bottom"] = true, ["border-left-color"] = true, ["border-right-color"] = true, ["border-top-color"] = true, ["border-bottom-color"] = true, ["colspan"] = true, ["graphic"] = true, ["padding"] = true, ["padding-top"] = true, ["padding-bottom"] = true, ["padding-left"] = true, ["padding-right"] = true, ["role"] = true, ["rowspan"] = true, ["rotate"] = true, ["valign"] = true },
    ["Tablerule"] = {["rulewidth"] = true, ["color"] = true, ["start"] = true, ["break-below"] = true, ["class"] = true, ["id"] = true },
    ["Textblock"] = {["angle"] = true, ["color"] = true, ["columns"] = true, ["columndistance"] = true, ["fontfamily"] = true, ["language"] = true, ["minheight"] = true, ["textformat"] = true, ["width"] = true },
    ["Text"] = {["color"] = true, ["fontfamily"] = true, ["textformat"] = true },
    ["Trace"] = {["assignments"] = true, ["grid"] = true, ["gridallocation"] = true, ["gridlocation"] = true, ["groups"] = true, ["hyphenation"] = true, ["kerning"] = true, ["objects"] = true, ["verbose"] = true, ["textformat"] = true, ["dump-structtree"] = true },
    ["Tr"] = {["align"] = true, ["background-color"] = true, ["break-below"] = true, ["data"] = true, ["minheight"] = true, ["parent"] = true, ["role"] = true, ["sethead"] = true, ["top-distance"] = true, ["valign"] = true },
    ["Transformation"] = {["matrix"] = true, ["flip"] = true, ["origin-x"] = true, ["origin-y"] = true },
    ["U"] = {["dashed"] = true, ["class"] = true, ["id"] = true },
    ["Ul"] = {["fontfamily"] = true },
    ["Until"] = {["test"] = true },
    ["URL"] = { },
    ["Value"] = {["select"] = true },
    ["VSpace"] = {["minheight"] = true, ["height"] = true },
    ["While"] = {["test"] = true },
}
